.. _{{ fullname }}:


.. title:: {{ fullname }}


.. raw:: html

    <center>
    <h3>

:ref:`src <source>`/**{{ name }}**

.. raw:: html

    </h3>
    </center>


.. auto{{ objtype }}:: {{ fullname }}
    :members:
    :private-members:
    :undoc-members:
